@@ -15,10 +15,6 @@
 from ducktape.cluster.cluster_spec import ClusterSpec
 from ducktape.tests.test import Test
 from ducktape.mark import ignore, parametrize
-from ducktape.mark.resource import cluster
-
-
-_flake = False
 
 
 class TestThingy(Test):
@@ -42,20 +38,3 @@ class TestThingy(Test):
 
     def test_failure(self):
         raise Exception("This failed")
-
-    def test_flaky(self):
-        global _flake
-        flake, _flake = _flake, not _flake
-        assert flake
-
-
-class ClusterTestThingy(Test):
-    """Fake ducktape test class"""
-
-    @cluster(num_nodes=10)
-    def test_bad_num_nodes(self):
-        pass
-
-    @cluster(num_nodes=0)
-    def test_good_num_nodes(self):
-        pass
